import { 
  csv, 
  select, 
  scaleOrdinal, 
  scaleLinear, 
  schemeCategory10,
  scaleBand,
  stackOrderNone,
  stackOffsetNone,
  axisLeft, 
  axisBottom,
  stack,
  max,
  extent,
  array
} from 'd3';

let data = [];
let stacking;

const svg = select('svg');
const height = +svg.attr('height');
const width = +svg.attr('width');
const margin = { left: 90, top: 30, right: 30, bottom: 40 };
const xValue = d => d.Layer;
const yValue = d => d.Depth;
var colorColumn = 'Layer';

const innerWidth = width - margin.left - margin.right;
const innerHeight = height - margin.top - margin.bottom;

const g = svg.append('g')
  .attr('transform', `translate(${margin.left}, ${margin.top})`);

const xAxisG = g.append('g')
  .attr('class', 'x axis')
  .attr('transform', `translate(0, ${innerHeight})`);

const yAxisG = g.append('g')
  .attr('class', 'y axis');


const render = (data) => {
const xScale = scaleBand()
  .domain(['Layer'])
  .range([0, innerWidth]);

const yScale = scaleLinear()
  .domain(extent(data, d => d.Depth))
  .range([innerHeight, 0]);
  
const yAxis = axisLeft(yScale);
const xAxis = axisBottom(xScale); 

const colorScale = scaleOrdinal(schemeCategory10);
  
  xAxisG.call(xAxis);
  yAxisG.call(yAxis);

  const bars = svg.selectAll("rect").data(data);
  bars.enter().append("rect")
    .attr("width", 100);
  bars
    .attr("x",100)
    .attr("y", 200)
    .attr("height", 200)
    .attr("fill", 'black');
  bars.exit().remove();
}

csv('https://vizhub.com/gsigroundwater/datasets/stackedBarChart.csv')
  .then(loadedData =>{
    loadedData.forEach(row =>
      data.push({
      Layer: row.Layer,
      Depth: row.Depth
  })
 )
  render(data);
});

